@@ -1,4 +1,4 @@
-/* $Id: hrestest.c 2409 2011-01-01 20:38:28Z dreibh $
+/* $Id: hrestest.c 2723 2012-11-13 13:05:20Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2011 by Thomas Dreibholz
+ * Copyright (C) 2002-2012 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,7 +53,6 @@ int main(int argc, char** argv)
    unsigned long long   statsLine     = 1;
    unsigned long long   startTimeStamp;
    unsigned long long   updateTimeStamp;
-   unsigned long long   requestTimeStamp;
    unsigned long long   responseTimeStamp;
    unsigned long long   successCount = 0;
    unsigned long long   failureCount = 0;
@@ -146,7 +145,6 @@ int main(int argc, char** argv)
    startTimeStamp  = getMicroTime();
    updateTimeStamp = 0;
    while(!breakDetected()) {
-      requestTimeStamp = getMicroTime();
       result = rsp_getaddrinfo((const unsigned char*)poolHandle, strlen(poolHandle),
                                &rspAddrInfo, items, 0);
       responseTimeStamp = getMicroTime();
