@@ -1,4 +1,4 @@
-/* $Id: loglevel.h 2409 2011-01-01 20:38:28Z dreibh $
+/* $Id: loglevel.h 2683 2012-06-08 13:11:14Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2011 by Thomas Dreibholz
+ * Copyright (C) 2002-2012 by Thomas Dreibholz
  *
  * Acknowledgements:
  * Realized in co-operation between Siemens AG and
@@ -40,6 +40,8 @@
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
+#else
+#error HAVE_CONFIG_H has not been defined?!
 #endif
 
 #include "tdtypes.h"
@@ -67,7 +69,7 @@ extern "C" {
 #define LOGLEVEL_VERBOSE5  9
 
 #ifndef MAX_LOGLEVEL
-#wanring MAX_LOGLEVEL should be defined in config.h!
+#warning MAX_LOGLEVEL should be defined in config.h!
 #define MAX_LOGLEVEL LOGLEVEL_VERBOSE5
 #endif
 
