@@ -1,4 +1,4 @@
-/* $Id: netutilities.h 2409 2011-01-01 20:38:28Z dreibh $
+/* $Id: netutilities.h 2725 2012-11-29 19:19:54Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2011 by Thomas Dreibholz
+ * Copyright (C) 2002-2012 by Thomas Dreibholz
  *
  * Acknowledgements:
  * Realized in co-operation between Siemens AG and
@@ -41,12 +41,12 @@
 
 #include "tdtypes.h"
 #include "sockaddrunion.h"
+#include "ext_socket.h"
 
 #include <stdio.h>
 #include <poll.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
-#include <ext_socket.h>
 
 
 #ifdef __cplusplus
@@ -71,11 +71,12 @@ int sctp_connectx(int                    sockfd,
 #endif
 
 #ifndef HAVE_SCTP_SEND
-ssize_t sctp_send(int                           sd,
-                  const void*                   data,
-                  size_t                        len,
-                  const struct sctp_sndrcvinfo* sinfo,
-                  int                           flags);
+#define sctp_send(a,b,c,d,e) sctp_send_wrapper(a,b,c,d,e)
+ssize_t sctp_send_wrapper(int                           sd,
+                          const void*                   data,
+                          size_t                        len,
+                          const struct sctp_sndrcvinfo* sinfo,
+                          int                           flags);
 #endif
 
 #ifndef HAVE_SCTP_SENDX
