@@ -1,4 +1,4 @@
-/* $Id: tcplikeserver.cc 2596 2011-10-27 14:08:44Z dreibh $
+/* $Id: tcplikeserver.cc 2695 2012-07-03 20:52:56Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2011 by Thomas Dreibholz
+ * Copyright (C) 2002-2012 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -439,7 +439,7 @@ void TCPLikeServer::poolElement(const char*          programTitle,
                            // waiting time. Therefore, cleaning them up is useful
                            // before accepting new sessions.
                            if(serverSet.handleRemovalsAndTimers() > 0) {
-                              int backlog = (int)(serverSet.getMaxThreads() - serverSet.getThreads());
+                              const int backlog = (int)(serverSet.getMaxThreads() - serverSet.getThreads());
                               if(rsp_listen(rserpoolSocket, 1 + backlog) < 0) {
                                  logerror("Unable to update backlog using rsp_listen()");
                               }
@@ -455,7 +455,7 @@ void TCPLikeServer::poolElement(const char*          programTitle,
                                         if(serviceThread) {
                                            if(serverSet.add(serviceThread)) {
                                               if(serviceThread->start()) {
-                                                 int backlog = (int)(serverSet.getMaxThreads() - serverSet.getThreads());
+                                                 const int backlog = (int)(serverSet.getMaxThreads() - serverSet.getThreads());
                                                  if(rsp_listen(rserpoolSocket, 1 + backlog) < 0) {
                                                     logerror("Unable to update backlog using rsp_listen()");
                                                     fflush(stdlog);
