@@ -1,4 +1,4 @@
-/* $Id: tdtypes.h 2409 2011-01-01 20:38:28Z dreibh $
+/* $Id: tdtypes.h 2733 2012-12-21 14:17:35Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //=====  //   //      //
@@ -9,7 +9,7 @@
  *
  * ------------- An Open Source RSerPool Simulation for OMNeT++ -------------
  *
- * Copyright (C) 2003-2011 by Thomas Dreibholz
+ * Copyright (C) 2003-2012 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,14 +37,8 @@
 #include "config.h"
 #endif
 
-#include <sys/types.h>
-
-#ifdef HAVE_STDINT_H
 #include <stdint.h>
-#endif
-#ifdef HAVE_SYS_INTTYPES_H
-#include <sys/inttypes.h>
-#endif
+#include <sys/types.h>
 #ifdef FreeBSD
 #include <machine/endian.h>
 #endif
